package v1

import (
	"dc_golang_server_1/cache"
	"github.com/gin-gonic/gin"
	"net/http"
	"strconv"
)

// GetProvinceList 获取省份列表
// @Tags 公用接口
// @Summary  获取全国省份列表
// @Description 获取带首字母的省份列表
// @Product json
// @Success 0 {object} []cache.DistrictStruct "按首字母排序好的列表,可直接用作展示"
// @Router /base/province [GET]
// @Security ApiKeyAuth
func GetProvinceList(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": cache.ProvinceMap,
	})
}

// GetCityList 获取城市或区县列表
// @Tags 公用接口
// @Summary  通过省份ID获取城市列表
// @Description 获取带首字母的城市列表
// @Param provinceID path integer true "省份id"
// @Product json
// @Success 0 {object} []cache.DistrictStruct "按首字母排序好的列表,可直接用作展示"
// @Router /base/city/{provinceID} [GET]
// @Security ApiKeyAuth
func GetCityList(c *gin.Context) {
	para, _ := strconv.Atoi(c.Param("id"))
	v, _ := cache.CityMap.Load(uint32(para)) // 如果查不到就直接返回空data
	// data, _ := v.([]cache.DistrictStruct)
	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": v,
	})
}

// GetCountyList 获取区县列表
// @Tags 公用接口
// @Summary  通过城市ID获取区县列表
// @Description 获取带首字母的城市列表
// @Param cityID path integer true "城市ID"
// @Product json
// @Success 0 {object} []cache.DistrictStruct "按首字母排序好的列表,可直接用作展示"
// @Router /base/county/{cityID} [GET]
// @Security ApiKeyAuth
func GetCountyList(c *gin.Context) {
	para, _ := strconv.Atoi(c.Param("id"))
	v, _ := cache.CountyMap.Load(uint32(para)) // 如果查不到就直接返回空data
	// data, _ := v.([]cache.DistrictStruct)
	c.JSON(http.StatusOK, gin.H{
		"code": 0,
		"data": v,
	})
}

type countyAreaRes struct {
	Name string `json:"name" example:"海科学校"`
	ID   int    `json:"id" example:"1"`
}

// GetAreaByCounty 根据区县ID获取学校列表
// @Tags 公用接口
// @Summary  根据区县ID获取学校列表
// @Description 根据区县ID获取学校列表
// @Param countyID path integer true "区县id" default(2725)
// @Product json
// @Success 0 {object} []countyAreaRes "排序好的学校列表,可直接用作展示"
// @Router /base/countyarea/{countyID} [GET]
// @Security ApiKeyAuth
func GetAreaByCounty(c *gin.Context) {
	para, _ := strconv.Atoi(c.Param("id")) //todo

	var data []countyAreaRes
	if para == 2725 {
		v, _ := cache.AreaMap.Load(uint32(1))  //
		if a, ok := v.(cache.AreaStruct); ok { //类型断言正确
			data = append(data, countyAreaRes{
				a.Name,
				1,
			})
		}
	}

	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": data,
	})
}

type locationAreaRes struct {
	Name     string `json:"name" example:"海科学校"`
	District string `json:"district" example:"四川省成都市温江区"`
	ID       int    `json:"id" example:"1"`
}

// GetAreaByLocation 根据经纬度获取附近学校列表
// @Tags 公用接口
// @Summary  根据经纬度获取附近20所学校列表
// @Description 根据经纬度获取附近20所学校列表
// @Param longitude query integer true "经度*1000000" default(103000000)
// @Param latitude query integer true "纬度*1000000" default(30000000)
// @Product json
// @Success 0 {object} []locationAreaRes "排序好的学校列表,可直接用作展示"
// @Router /base/locarea [GET]
// @Security ApiKeyAuth
func GetAreaByLocation(c *gin.Context) {
	longitude, err := strconv.Atoi(c.Query("longitude"))
	if err != nil {
		c.JSON(http.StatusOK, gin.H{
			"code":    2001,
			"message": "经度格式错误",
		})
		return
	}
	if longitude < -180000000 || longitude > 180000000 {
		c.JSON(http.StatusOK, gin.H{
			"code":    2001,
			"message": "经度范围错误",
		})
		return
	}
	latitude, err := strconv.Atoi(c.Query("latitude"))
	if err != nil {
		c.JSON(http.StatusOK, gin.H{
			"code":    2001,
			"message": "纬度格式错误",
		})
		return
	}
	if latitude < -90000000 || latitude > 90000000 {
		c.JSON(http.StatusOK, gin.H{
			"code":    2001,
			"message": "纬度范围错误",
		})
		return
	}

	var data []locationAreaRes
	v, _ := cache.AreaMap.Load(uint32(1))  // todo 根据经纬度计算距离 还要看status 和 用户的权限
	if a, ok := v.(cache.AreaStruct); ok { //类型断言正确
		data = append(data, locationAreaRes{
			a.Name,
			"四川省成都市温江区",
			1,
		})
	}

	c.JSON(http.StatusOK, gin.H{
		"code": SUCCSE,
		"data": data,
	})
}
